@@ -35,7 +35,6 @@ class EnergySiteDevice:
         self._id: int = data["id"]
         self._energy_site_id: int = data["energy_site_id"]
         self._site_name: Text = data.get("site_name", f"{self._energy_site_id}")
-        self._solar_type: Text = data["solar_type"]
         self._controller = controller
         self.should_poll: bool = True
         self.type: Text = "device"
@@ -50,26 +49,21 @@ class EnergySiteDevice:
 
     def id(self) -> int:
         # pylint: disable=invalid-name
-        """Return the id of this Vehicle."""
+        """Return the id."""
         return self._id
 
     def energy_site_id(self) -> int:
-        """Return the vehicle_id of this Vehicle."""
+        """Return the energy_site_id."""
         return self._energy_site_id
 
     def site_name(self) -> Text:
-        """Return the car name of this Vehicle."""
+        """Return the site name."""
         return self._site_name
 
-    @property
-    def solar_type(self) -> Text:
-        """Return the type of this Vehicle."""
-        return self._solar_type
-
     async def async_update(
         self, wake_if_asleep: bool = False, force: bool = False
     ) -> None:
-        """Update the vehicle data.
+        """Update the energy site data.
 
         This function will call a controller update.
         """
@@ -80,7 +74,7 @@ class EnergySiteDevice:
 
     # pylint: disable=no-self-use
     def refresh(self) -> None:
-        """Refresh the vehicle data.
+        """Refresh the energy site data.
 
         This assumes the controller has already been updated. This should be
         called by inherited classes so the overall vehicle information is updated.
@@ -111,22 +105,61 @@ class PowerSensor(EnergySiteDevice):
 
         """
         super().__init__(data, controller)
-        self.__power: float = data["solar_power"]
-        self.__generating_status: bool = None
-        self.type = "solar panel"
         self.measurement = "W"
         self.hass_type = "sensor"
         self._device_class: Text = "power"
         self._state_class: Text = "measurement"
-        self.name = self._name()
-        self.uniq_name = self._uniq_name()
         self.bin_type = 0x4
 
     async def async_update(self, wake_if_asleep=False, force=False) -> None:
-        """Update the temperature."""
+        """Update the site info."""
         await super().async_update(wake_if_asleep=wake_if_asleep)
         self.refresh()
 
+    @property
+    def device_class(self) -> Text:
+        """Return the HA device class."""
+        return self._device_class
+
+    @property
+    def state_class(self) -> Text:
+        """Return the HA state class."""
+        return self._state_class
+
+
+class SolarPowerSensor(PowerSensor):
+    """Home-assistant class of power sensors for Tesla Energy Sites (Solar Panels).
+
+    This is intended to be partially inherited by a Home-Assitant entity.
+    """
+
+    def __init__(self, data, controller):
+        """Initialize the solar panel sensor."""
+        super().__init__(data, controller)
+        self._solar_type: Text = data["solar_type"]
+        self.__solar_power: float = data["solar_power"]
+        self.__generating_status: bool = None
+        self.type = "solar panel"
+        self.name = self._name()
+        self.uniq_name = self._uniq_name()
+
+    def get_value(self) -> float:
+        """Return solar power."""
+        return self.__solar_power
+
+    def get_power(self):
+        """Get solar power."""
+        return self.__solar_power
+
+    def get_generating_status(self):
+        """Get generating status."""
+        return self.__generating_status
+
+    @property
+    def solar_type(self) -> Text:
+        """Return the solar type."""
+        return self._solar_type
+
     def refresh(self) -> None:
         """Refresh data.
 
@@ -139,34 +172,84 @@ class PowerSensor(EnergySiteDevice):
             # Note: Some systems that pre-date Tesla aquisition of SolarCity will have `grid_status: Unknown`,
             # but will have solar power values. At the same time, newer systems will report spurious reads of 0 Watts
             # and grid status unknown. If solar power is 0 return null.
-            if "grid_status" in data and data["grid_status"] == "Unknown" and data["solar_power"] == 0:
+            if (
+                "grid_status" in data
+                and data["grid_status"] == "Unknown"
+                and data["solar_power"] == 0
+            ):
                 _LOGGER.debug("Spurious energy site power read")
                 return
 
-            self.__power = data["solar_power"]
+            self.__solar_power = data["solar_power"]
             if data["solar_power"] is not None:
                 self.__generating_status = (
                     "Generating" if data["solar_power"] > 0 else "Idle"
                 )
 
+
+class LoadPowerSensor(PowerSensor):
+    """Home-assistant class for load power sensors for Tesla Energy Sites (Solar Panels).
+
+    This is intended to be partially inherited by a Home-Assitant entity.
+    """
+
+    def __init__(self, data, controller):
+        """Initialize the load power sensor."""
+        super().__init__(data, controller)
+        self.__load_power: float = data["load_power"]
+        self.type = "load power"
+        self.name = self._name()
+        self.uniq_name = self._uniq_name()
+
     def get_value(self) -> float:
-        """Return the battery level."""
-        return self.__power
+        """Return load power."""
+        return self.__load_power
 
-    def get_power(self):
-        """Get inside temperature."""
-        return self.__power
+    def get_load_power(self):
+        """Get load power (home consumption)."""
+        return self.__load_power
 
-    def get_generating_status(self):
-        """Get outside temperature."""
-        return self.__generating_status
+    def refresh(self) -> None:
+        """Refresh data.
 
-    @property
-    def device_class(self) -> Text:
-        """Return the HA device class."""
-        return self._device_class
+        This assumes the controller has already been updated
+        """
+        super().refresh()
+        data = self._controller.get_power_params(self._id)
 
-    @property
-    def state_class(self) -> Text:
-        """Return the HA state class."""
-        return self._state_class
+        if data:
+            self.__load_power = data["load_power"]
+
+
+class GridPowerSensor(PowerSensor):
+    """Home-assistant class for grid power sensors for Tesla Energy Sites (Solar Panels).
+
+    This is intended to be partially inherited by a Home-Assitant entity.
+    """
+
+    def __init__(self, data, controller):
+        """Initialize the grid power sensor."""
+        super().__init__(data, controller)
+        self.__grid_power: float = data["grid_power"]
+        self.type = "grid power"
+        self.name = self._name()
+        self.uniq_name = self._uniq_name()
+
+    def get_value(self) -> float:
+        """Return grid power."""
+        return self.__grid_power
+
+    def get_grid_power(self):
+        """Get grid power (grid import/export)."""
+        return self.__grid_power
+
+    def refresh(self) -> None:
+        """Refresh data.
+
+        This assumes the controller has already been updated
+        """
+        super().refresh()
+        data = self._controller.get_power_params(self._id)
+
+        if data:
+            self.__grid_power = data["grid_power"]
